from .genyaml import GenHelmChartValue
from .util import log
import click


@click.command()
@click.option('--data', '-d',
              help='Supply payload in jsonstring format e.g {"name": "app-1", "version": "v1"} ')
def main(data):
    log('yaml file generator', 'blue')
    gen_yaml = GenHelmChartValue(data)
    gen_yaml.build_yaml()
    click.echo('successfully generate yaml file')
    return log('Success: ->', 'green')


if __name__ == '__main__':
    main(prog_name="yamlgen")



import yaml
import json
from .util import log, validate_yaml


class GenHelmChartValue:

    def __init__(self, data):
        self.data = json.loads(data)

    def build_yaml(self):
        try:
            response = yaml.dump(self.data, default_flow_style=False, sort_keys=False)
            is_valid, contents = validate_yaml(response)

            if not is_valid:
                log('Error occurred: -> yaml contents validation failed.', 'red')
                raise Exception('Error occurred: -> yaml contents validation failed.')

            build_policy = open('values.yaml', 'w')
            build_policy.write(contents)
            build_policy.close()
            return log('Success: ->' + json.dumps(contents), 'green')
        except Exception as e:
            log('Error occurred: -> {}'.format(e), 'red')
            raise Exception('Error occurred: -> {}'.format(e))
